@@ -1,16 +1,16 @@
 ### Steven R. Chesnut, Danny Squire, Terrence D. Jorgensen
-### Last updated: 10 January 2021
+### Last updated: 12 March 2025
 
 
 
 ##' Quark
 ##'
-##' The \code{quark} function provides researchers with the ability to calculate
+##' The `quark` function provides researchers with the ability to calculate
 ##' and include component scores calculated by taking into account the variance
 ##' in the original dataset and all of the interaction and polynomial effects of
 ##' the data in the dataset.
 ##'
-##' The \code{quark} function calculates these component scores by first filling
+##' The `quark` function calculates these component scores by first filling
 ##' in the data via means of multiple imputation methods and then expanding the
 ##' dataset by aggregating the non-overlapping interaction effects between
 ##' variables by calculating the mean of the interactions and polynomial
@@ -22,21 +22,21 @@
 ##' contains the means of the polynomial effects (squares and cubes), and the
 ##' final third contains the means of the non-overlapping interaction effects. A
 ##' full principal componenent analysis is conducted and the individual
-##' components are retained. The subsequent \code{\link{combinequark}} function
+##' components are retained. The subsequent [combinequark()] function
 ##' provides researchers the control in determining how many components to
 ##' extract and retain. The function returns the dataset as submitted (with
 ##' missing values) and the component scores as requested for a more accurate
 ##' multiple imputation in subsequent steps.
 ##'
-##' @param data The data frame is a required component for \code{quark}.  In
-##' order for \code{quark} to process a data frame, it must not contain any
+##' @param data The data frame is a required component for `quark`.  In
+##' order for `quark` to process a data frame, it must not contain any
 ##' factors or text-based variables.  All variables must be in numeric format.
 ##' Identifiers and dates can be left in the data; however, they will need to be
-##' identified under the \code{id} argument.
+##' identified under the `id` argument.
 ##' @param id Identifiers and dates within the dataset will need to be
-##' acknowledged as \code{quark} cannot process these.  By acknowledging the
+##' acknowledged as `quark` cannot process these.  By acknowledging the
 ##' identifiers and dates as a vector of column numbers or variable names,
-##' \code{quark} will remove them from the data temporarily to complete its main
+##' `quark` will remove them from the data temporarily to complete its main
 ##' processes.  Among many potential issues of not acknowledging identifiers and
 ##' dates are issues involved with imputation, product and polynomial effects,
 ##' and principal component analysis.
@@ -44,11 +44,11 @@
 ##' used when the imputation procedures in mice fail.  Under some circumstances,
 ##' mice cannot calculate missing values due to issues with extreme missingness.
 ##' Should an error present itself stating a failure due to not having any
-##' columns selected, set the argument \code{order = 2} in order to reorder the
-##' imputation method procedure.  Otherwise, use the default \code{order = 1}.
-##' @param silent If \code{FALSE}, the details of the \code{quark} process are
+##' columns selected, set the argument `order = 2` in order to reorder the
+##' imputation method procedure.  Otherwise, use the default `order = 1`.
+##' @param silent If `FALSE`, the details of the `quark` process are
 ##' printed.
-##' @param \dots additional arguments to pass to \code{\link[mice]{mice}}.
+##' @param \dots additional arguments to pass to [mice::mice()].
 ##'
 ##' @return The output value from using the quark function is a list. It will
 ##' return a list with 7 components.
@@ -75,13 +75,13 @@
 ##'
 ##' Terrence D. Jorgensen (University of Amsterdam)
 ##'
-##' The PCA code is copied and modified from the \code{FactoMineR} package.
+##' The PCA code is copied and modified from the `FactoMineR` package.
 ##'
-##' @seealso \code{\link{combinequark}}
+##' @seealso [combinequark()]
 ##'
 ##' @references Howard, W. J., Rhemtulla, M., & Little, T. D. (2015). Using
 ##' Principal Components as Auxiliary Variables in Missing Data Estimation.
-##' \emph{Multivariate Behavioral Research, 50}(3), 285--299.
+##' *Multivariate Behavioral Research, 50*(3), 285--299.
 ##' \doi{10.1080/00273171.2014.999267}
 ##'
 ##' @examples
@@ -92,7 +92,7 @@
 ##' misspat <- matrix(runif(nrow(dat) * 9) < 0.3, nrow(dat))
 ##' dat[misspat] <- NA
 ##' dat <- cbind(HolzingerSwineford1939[,1:3], dat)
-##' \dontrun{
+##' \donttest{
 ##' quark.list <- quark(data = dat, id = c(1, 2))
 ##'
 ##' final.data <- combinequark(quark = quark.list, percent = 80)
@@ -123,7 +123,7 @@ quark <- function(data, id, order = 1, silent = FALSE, ...){
   final.collect$Used_Data <- data[,-c(id)]
   ##FIXME 26-June-2018: Terrence had to add a logical check for whether mice
   ##                    is installed, otherwise won't pass CRAN checks.
-  checkMice <- requireNamespace("mice")
+  checkMice <- requireNamespace("mice", quietly = TRUE)
   if (!checkMice) {
     message('The quark function requires the "mice" package to be installed.')
     return(invisible(NULL))
@@ -143,13 +143,13 @@ quark <- function(data, id, order = 1, silent = FALSE, ...){
 
 ##' Combine the results from the quark function
 ##'
-##' This function builds upon the \code{\link{quark}} function to provide a
+##' This function builds upon the [quark()] function to provide a
 ##' final dataset comprised of the original dataset provided to
-##' \code{\link{quark}} and enough principal components to be able to account
+##' [quark()] and enough principal components to be able to account
 ##' for a certain level of variance in the data.
 ##'
 ##'
-##' @param quark Provide the \code{\link{quark}} object that was returned.  It
+##' @param quark Provide the [quark()] object that was returned.  It
 ##' should be a list of objects.  Make sure to include it in its entirety.
 ##' @param percent Provide a percentage of variance that you would like to have
 ##' explained.  That many components (columns) will be extracted and kept with
@@ -163,7 +163,7 @@ quark <- function(data, id, order = 1, silent = FALSE, ...){
 ##' @author Steven R. Chesnut (University of Southern Mississippi
 ##' \email{Steven.Chesnut@@usm.edu})
 ##'
-##' @seealso \code{\link{quark}}
+##' @seealso [quark()]
 ##'
 ##' @examples
 ##'
@@ -293,7 +293,6 @@ aImp <- function(data, silent = FALSE, ...) {
   miceArgs$maxit <- 1
   miceArgs$m <- 1
   miceArgs$printFlag <- !silent
-  requireNamespace("mice")
   if (!("package:mice" %in% search())) attachNamespace("mice")
   if (!silent) cat("Starting Algorithm Imputation...\n")
   impData <- mice::complete(do.call("mice", miceArgs))
