@@ -1,8 +1,11 @@
 ### Terrence D. Jorgensen & Yves Rosseel
-### Last updated: 10 January 2021
+### Last updated: 12 March 2025
 ### Pooled score test (= Lagrange Multiplier test) for multiple imputations
 ### Borrowed source code from lavaan/R/lav_test_score.R
 
+### DEPRECATED: 16 June 2024
+### supplanted by lavaan.mi package
+
 ## this function can run two modes:
 ## MODE 1: 'add'
 ##   add new parameters that are currently not included in de model
@@ -23,97 +26,97 @@
 ##' by pooling the complete-data score-test statistics across imputed data sets
 ##' (i.e., "D2"; Li et al., 1991).
 ##'
-##' @aliases lavTestScore.mi
+## @aliases lavTestScore.mi
 ##' @importFrom lavaan lavListInspect parTable
 ##' @importFrom stats cov pchisq pf
 ##' @importFrom methods getMethod
 ##'
-##' @param object An object of class \code{\linkS4class{lavaan.mi}}.
-##' @param add Either a \code{character} string (typically between single
+##' @param object An object of class [OLDlavaan.mi-class].
+##' @param add Either a `character` string (typically between single
 ##'   quotes) or a parameter table containing additional (currently
 ##'   fixed-to-zero) parameters for which the score test must be computed.
-##' @param release Vector of \code{integer}s. The indices of the \emph{equality}
+##' @param release Vector of `integer`s. The indices of the *equality*
 ##'  constraints that should be released. The indices correspond to the order of
 ##'  the equality constraints as they appear in the parameter table.
-##' @param test \code{character} indicating which pooling method to use.
-##'   \code{"D1"} requests Mansolf, Jorgensen, & Enders' (2020) proposed
+##' @param test `character` indicating which pooling method to use.
+##'   `"D1"` requests Mansolf, Jorgensen, & Enders' (2020) proposed
 ##'   Wald-like test for pooling the gradient and information, which are then
-##'   used to calculate score-test statistics in the usual manner. \code{"D2"}
+##'   used to calculate score-test statistics in the usual manner. `"D2"`
 ##'   (default because it is less computationall intensive) requests to pool the
 ##'   complete-data score-test statistics from each imputed data set, then pool
 ##'   them across imputations, described by Li et al. (1991) and Enders (2010).
-##' @param scale.W \code{logical}. If \code{FALSE}, the pooled
+##' @param scale.W `logical`. If `FALSE`, the pooled
 ##'   information matrix is calculated as the weighted sum of the
 ##'   within-imputation and between-imputation components. Otherwise, the pooled
 ##'   information is calculated by scaling the within-imputation component by
 ##'   the average relative increase in variance (ARIV; Enders, 2010, p. 235),
-##'   which is \emph{only} consistent when requesting the \emph{F} test (i.e.,
-##'   \code{asymptotic = FALSE}.  Ignored (irrelevant) if \code{test = "D2"}.
-##' @param omit.imps \code{character} vector specifying criteria for omitting
+##'   which is *only* consistent when requesting the *F* test (i.e.,
+##'   `asymptotic = FALSE`.  Ignored (irrelevant) if `test = "D2"`.
+##' @param omit.imps `character` vector specifying criteria for omitting
 ##'   imputations from pooled results.  Can include any of
-##'   \code{c("no.conv", "no.se", "no.npd")}, the first 2 of which are the
+##'   `c("no.conv", "no.se", "no.npd")`, the first 2 of which are the
 ##'   default setting, which excludes any imputations that did not
 ##'   converge or for which standard errors could not be computed.  The
-##'   last option (\code{"no.npd"}) would exclude any imputations which
+##'   last option (`"no.npd"`) would exclude any imputations which
 ##'   yielded a nonpositive definite covariance matrix for observed or
 ##'   latent variables, which would include any "improper solutions" such
 ##'   as Heywood cases. Specific imputation numbers can also be included in this
 ##'   argument, in case users want to  apply their own custom omission criteria
 ##'   (or simulations can use different numbers of imputations without
 ##'   redundantly refitting the model).
-##' @param asymptotic \code{logical}. If \code{FALSE} (default when using
-##'   \code{add} to test adding fixed parameters to the model), the pooled test
-##'   will be returned as an \emph{F}-distributed variable with numerator
-##'   (\code{df1}) and denominator (\code{df2}) degrees of freedom.
-##'   If \code{TRUE}, the pooled \emph{F} statistic will be multiplied by its
-##'   \code{df1} on the assumption that its \code{df2} is sufficiently large
+##' @param asymptotic `logical`. If `FALSE` (default when using
+##'   `add` to test adding fixed parameters to the model), the pooled test
+##'   will be returned as an *F*-distributed variable with numerator
+##'   (`df1`) and denominator (`df2`) degrees of freedom.
+##'   If `TRUE`, the pooled *F* statistic will be multiplied by its
+##'   `df1` on the assumption that its `df2` is sufficiently large
 ##'   enough that the statistic will be asymptotically \eqn{\chi^2} distributed
-##'   with \code{df1}. When using the \code{release} argument, \code{asymptotic}
-##'   will be set to \code{TRUE} because (A)RIV can only be calculated for
-##'   \code{add}ed parameters.
-##' @param univariate \code{logical}. If \code{TRUE}, compute the univariate
+##'   with `df1`. When using the `release` argument, `asymptotic`
+##'   will be set to `TRUE` because (A)RIV can only be calculated for
+##'   `add`ed parameters.
+##' @param univariate `logical`. If `TRUE`, compute the univariate
 ##'   score statistics, one for each constraint.
-##' @param cumulative \code{logical}. If \code{TRUE}, order the univariate score
+##' @param cumulative `logical`. If `TRUE`, order the univariate score
 ##'   statistics from large to small, and compute a series of multivariate
 ##'   score statistics, each time including an additional constraint in the test.
-##' @param epc \code{logical}. If \code{TRUE}, and we are releasing existing
+##' @param epc `logical`. If `TRUE`, and we are releasing existing
 ##'   constraints, compute the expected parameter changes for the existing
-##'   (free) parameters (and any specified with \code{add}), if all constraints
-##'   were released. For EPCs associated with a particular (1-\emph{df})
-##'   constraint, only specify one parameter in \code{add} or one constraint in
-##'   \code{release}.
-##' @param standardized If \code{TRUE}, two extra columns (\code{sepc.lv} and
-##'   \code{sepc.all}) in the \code{$epc} table will contain standardized values
-##'   for the EPCs. See \code{\link{lavTestScore}}.
-##' @param cov.std \code{logical}. See \code{\link{standardizedSolution}}.
-##' @param verbose \code{logical}. Not used for now.
-##' @param warn \code{logical}. If \code{TRUE}, print warnings if they occur.
-##' @param information \code{character} indicating the type of information
-##'   matrix to use (check \code{\link{lavInspect}} for available options).
-##'   \code{"expected"} information is the default, which provides better
+##'   (free) parameters (and any specified with `add`), if all constraints
+##'   were released. For EPCs associated with a particular (1-*df*)
+##'   constraint, only specify one parameter in `add` or one constraint in
+##'   `release`.
+##' @param standardized If `TRUE`, two extra columns (`sepc.lv` and
+##'   `sepc.all`) in the `$epc` table will contain standardized values
+##'   for the EPCs. See [lavaan::lavTestScore()].
+##' @param cov.std `logical`. See [lavaan::standardizedSolution()].
+##' @param verbose `logical`. Not used for now.
+##' @param warn `logical`. If `TRUE`, print warnings if they occur.
+##' @param information `character` indicating the type of information
+##'   matrix to use (check [lavaan::lavInspect()] for available options).
+##'   `"expected"` information is the default, which provides better
 ##'   control of Type I errors.
 ##'
 ##' @return
-##'  A list containing at least one \code{data.frame}:
+##'  A list containing at least one `data.frame`:
 ##'  \itemize{
-##'    \item{\code{$test}: The total score test, with columns for the score
-##'      test statistic (\code{X2}), its degrees of freedom (\code{df}), its
-##'      \emph{p} value under the \eqn{\chi^2} distribution (\code{p.value}),
-##'      and if \code{asymptotic=FALSE}, the average relative invrease in
-##'      variance (ARIV) used to calculate the denominator \emph{df} is also
+##'    \item{`$test`: The total score test, with columns for the score
+##'      test statistic (`X2`), its degrees of freedom (`df`), its
+##'      *p* value under the \eqn{\chi^2} distribution (`p.value`),
+##'      and if `asymptotic=FALSE`, the average relative invrease in
+##'      variance (ARIV) used to calculate the denominator *df* is also
 ##'      returned as a missing-data diagnostic, along with the fraction missing
 ##'      information (FMI = ARIV / (1 + ARIV)).}
-##'    \item{\code{$uni}: Optional (if \code{univariate=TRUE}).
-##'      Each 1-\emph{df} score test, equivalent to modification indices. Also
-##'      includes EPCs if \code{epc=TRUE}, and RIV and FMI if
-##'      \code{asymptotic=FALSE}.}
-##'    \item{\code{$cumulative}: Optional (if \code{cumulative=TRUE}).
-##'      Cumulative score tests, with ARIV and FMI if \code{asymptotic=FALSE}.}
-##'    \item{\code{$epc}: Optional (if \code{epc=TRUE}). Parameter estimates,
+##'    \item{`$uni`: Optional (if `univariate=TRUE`).
+##'      Each 1-*df* score test, equivalent to modification indices. Also
+##'      includes EPCs if `epc=TRUE`, and RIV and FMI if
+##'      `asymptotic=FALSE`.}
+##'    \item{`$cumulative`: Optional (if `cumulative=TRUE`).
+##'      Cumulative score tests, with ARIV and FMI if `asymptotic=FALSE`.}
+##'    \item{`$epc`: Optional (if `epc=TRUE`). Parameter estimates,
 ##'      expected parameter changes, and expected parameter values if ALL
 ##'      the tested constraints were freed.}
 ##'  }
-##' See \code{\link[lavaan]{lavTestScore}} for details.
+##' See [lavaan::lavTestScore()] for details.
 ##'
 ##' @author
 ##'   Terrence D. Jorgensen (University of Amsterdam; \email{TJorgensen314@@gmail.com})
@@ -121,65 +124,49 @@
 ##' Adapted from \pkg{lavaan} source code, written by
 ##'   Yves Rosseel (Ghent University; \email{Yves.Rosseel@@UGent.be})
 ##'
-##' \code{test = "D1"} method proposed by
+##' `test = "D1"` method proposed by
 ##'   Maxwell Mansolf (University of California, Los Angeles;
 ##'   \email{mamansolf@@gmail.com})
 ##'
 ##' @references
 ##'   Bentler, P. M., & Chou, C.-P. (1992). Some new covariance structure model
-##'   improvement statistics. \emph{Sociological Methods & Research, 21}(2),
+##'   improvement statistics. *Sociological Methods & Research, 21*(2),
 ##'   259--282. \doi{10.1177/0049124192021002006}
 ##'
-##'   Enders, C. K. (2010). \emph{Applied missing data analysis}.
+##'   Enders, C. K. (2010). *Applied missing data analysis*.
 ##'   New York, NY: Guilford.
 ##'
 ##'   Li, K.-H., Meng, X.-L., Raghunathan, T. E., & Rubin, D. B. (1991).
-##'   Significance levels from repeated \emph{p}-values with multiply-imputed
-##'   data. \emph{Statistica Sinica, 1}(1), 65--92. Retrieved from
-##'   \url{https://www.jstor.org/stable/24303994}
+##'   Significance levels from repeated *p*-values with multiply-imputed
+##'   data. *Statistica Sinica, 1*(1), 65--92. Retrieved from
+##'   <https://www.jstor.org/stable/24303994>
 ##'
 ##'   Mansolf, M., Jorgensen, T. D., & Enders, C. K. (2020). A multiple
 ##'   imputation score test for model modification in structural equation
-##'   models. \emph{Psychological Methods, 25}(4), 393--411.
+##'   models. *Psychological Methods, 25*(4), 393--411.
 ##'   \doi{10.1037/met0000243}
 ##'
-##' @seealso \code{\link[lavaan]{lavTestScore}}
+##' @seealso [lavaan::lavTestScore()]
 ##'
 ##' @examples
-##'  \dontrun{
-##' ## impose missing data for example
-##' HSMiss <- HolzingerSwineford1939[ , c(paste("x", 1:9, sep = ""),
-##'                                       "ageyr","agemo","school")]
-##' set.seed(12345)
-##' HSMiss$x5 <- ifelse(HSMiss$x5 <= quantile(HSMiss$x5, .3), NA, HSMiss$x5)
-##' age <- HSMiss$ageyr + HSMiss$agemo/12
-##' HSMiss$x9 <- ifelse(age <= quantile(age, .3), NA, HSMiss$x9)
 ##'
-##' ## impute missing data
-##' library(Amelia)
-##' set.seed(12345)
-##' HS.amelia <- amelia(HSMiss, m = 20, noms = "school", p2s = FALSE)
-##' imps <- HS.amelia$imputations
-##'
-##' ## specify CFA model from lavaan's ?cfa help page
-##' HS.model <- '
-##'   speed =~ c(L1, L1)*x7 + c(L1, L1)*x8 + c(L1, L1)*x9
-##' '
-##'
-##' out <- cfa.mi(HS.model, data = imps, group = "school", std.lv = TRUE)
-##'
-##' ## Mode 1: Score test for releasing equality constraints
-##'
-##' ## default test: Li et al.'s (1991) "D2" method
-##' lavTestScore.mi(out, cumulative = TRUE)
-##' ## Li et al.'s (1991) "D1" method
-##' lavTestScore.mi(out, test = "D1")
-##'
-##' ## Mode 2: Score test for adding currently fixed-to-zero parameters
-##' lavTestScore.mi(out, add = 'x7 ~~ x8 + x9')
-##'
-##' }
+##' ## See the new lavaan.mi package
 ##'
+##' @name lavTestScore.mi-deprecated
+##' @usage
+##' lavTestScore.mi(object, add = NULL, release = NULL,
+##'                 test = c("D2","D1"), scale.W = !asymptotic,
+##'                 omit.imps = c("no.conv","no.se"),
+##'                 asymptotic = is.null(add),
+##'                 univariate = TRUE, cumulative = FALSE,
+##'                 epc = FALSE, standardized = epc, cov.std = epc,
+##'                 verbose = FALSE, warn = TRUE, information = "expected")
+##' @seealso [semTools-deprecated()]
+##' @keywords internal
+NULL
+
+
+##' @rdname semTools-deprecated
 ##' @export
 lavTestScore.mi <- function(object, add = NULL, release = NULL,
                             test = c("D2","D1"), scale.W = !asymptotic,
@@ -188,7 +175,20 @@ lavTestScore.mi <- function(object, add = NULL, release = NULL,
                             univariate = TRUE, cumulative = FALSE,
                             epc = FALSE, standardized = epc, cov.std = epc,
                             verbose = FALSE, warn = TRUE, information = "expected") {
-  stopifnot(inherits(object, "lavaan.mi"))
+
+  .Deprecated(msg = c("\nThe runMI() and related lavaan.mi functions have been",
+                      " deprecated and will cease to be included in future ",
+                      "versions of semTools.\n\nSupport is still provided for ",
+                      "analyzing lavaan.mi-class objects (e.g., compRelSEM() ",
+                      "can estimate reliability using pooled results), which ",
+                      "can now be created using the lavaan.mi package.\n\nThe ",
+                      "deprecated runMI() function now creates an object of ",
+                      "class OLDlavaan.mi, which can be analyzed using the ",
+                      "deprecated functions in semTools, like lavTestLRT.mi(),",
+                      " that have been updated and improved in the lavaan.mi ",
+                      "package.\n\nFind more details help('semTools-deprecated)"))
+
+  stopifnot(inherits(object, "OLDlavaan.mi"))
   lavoptions <- object@Options
 
   useImps <- rep(TRUE, length(object@DataList))
@@ -426,8 +426,8 @@ lavTestScore.mi <- function(object, add = NULL, release = NULL,
         ADD$user  <- rep(10, nrow(ADD))
       } else stop("'add' must be lavaan model syntax or a parameter table.")
       # nR <- try(nrow(ADD), silent = TRUE)
-      # if (class(nR) == "try-error" || is.null(nR)) return(list(gradient = NULL,
-      #                                                          information = NULL))
+      # if (inherits(nR, "try-error") || is.null(nR)) return(list(gradient = NULL,
+      #                                                           information = NULL))
       # ADD$free <- rep(1L, nR)
       # ADD$user <- rep(10L, nR)
 
@@ -754,7 +754,7 @@ lavTestScore.mi <- function(object, add = NULL, release = NULL,
     EPC.all <- 1 * as.numeric(score %*%  Z1.plus1)
 
     # create epc table for the 'free' parameters
-    myCoefs <- getMethod("coef","lavaan.mi")(object, omit.imps = omit.imps)
+    myCoefs <- getMethod("coef","OLDlavaan.mi")(object, omit.imps = omit.imps)
     myCols <- c("lhs","op","rhs","user")
     if (ngroups > 1L) myCols <- c(myCols, "block","group")
     if (nlevels > 1L) myCols <- c(myCols, "block","level")
@@ -795,7 +795,8 @@ lavTestScore.mi <- function(object, add = NULL, release = NULL,
       EPC.sign <- sign(LIST$epc)
 
       ## pooled estimates for standardizedSolution()
-      pooledest <- getMethod("coef", "lavaan.mi")(object, omit.imps = omit.imps)
+      pooledest <- getMethod("coef", "OLDlavaan.mi")(object,
+                                                     omit.imps = omit.imps)
       ## update @Model@GLIST for standardizedSolution(..., GLIST=)
       object@Model <- lavaan::lav_model_set_parameters(object@Model, x = pooledest)
 
